@@ -8,10 +8,6 @@ def Mod(num):
 
 
 class Math_:
-
-    def __init__(self):
-        pass
-
     def COS(self,ugl):
         return math.cos(ugl)
 
@@ -97,3 +93,5 @@ class Vec2_:
 
 
 
+
+
