@@ -104,7 +104,7 @@ class Particles():
 
     class Rect():
         def __init__(self,
-                        surf,
+                        surf:GL.Display_init_,
                         rect,
                         shape_data,
                         color_randoming=False,
@@ -152,9 +152,11 @@ class Particles():
                         size_randoming = False,
                         size_min_max = [],
                         size_resize_timer = 1,
-                        vector_speed_randoming_angle = 90
-                    
+                        vector_speed_randoming_angle = 90,
+                        shader = 'pos',
+                        draw_surf=None
                         ) -> None:
+                self.shader = shader
                 self.vector_speed_randoming_angle = vector_speed_randoming_angle
                 self.size_resize_timer = size_resize_timer
                 self.size_randoming = size_randoming
@@ -219,6 +221,7 @@ class Particles():
                 self.color_index = color_index
                 self.randoming_image = randomig_iamge
                 self.end_mouse_pos = 0
+                self.draw_surf = draw_surf
 
 
                 self.phisics_color = None
@@ -298,9 +301,9 @@ class Particles():
                 if self.time%self.spawn_time==0:
                     self.end_line_pos = [self.posx,self.posy]
                     self.posx = int(self.posx) ; self.posy = int(self.posy)
-                    if self.surf.IN_WINDOW([self.posx,self.posy]):
-                        if self.surf.GET_COLOR(self.posx,self.posy)!=self.phisics_color:
-                            for i in range(self.partcle_count):
+                    
+
+                    for i in range(self.partcle_count):
                                 pos = Vec2_([
                                     random.randint(self.posx,self.posx+self.width),
                                     random.randint(self.posy,self.posy+self.height)
@@ -324,6 +327,13 @@ class Particles():
                                         color =Color_._rgb('r','r','r').COLOR
                                     if self.size_randoming:
                                         self.shape_widt = random.randint(self.size_min_max[0],self.size_min_max[1])
+                                    if self.shader == 'rg':
+                                        color = [pos.vector.x/self.surf.GET_WIN_WIDTH()*255,pos.vector.y/self.surf.GET_WIN_HEIGHT()*255,0]
+                                    elif self.shader == 'rb':
+                                        color = [pos.vector.x/self.surf.GET_WIN_WIDTH()*255,0,pos.vector.y/self.surf.GET_WIN_HEIGHT()*255]
+                                    elif self.shader == 'bg':
+                                        color = [0,pos.vector.x/self.surf.GET_WIN_WIDTH()*255,pos.vector.y/self.surf.GET_WIN_HEIGHT()*255]
+
                                     particle = [pos,self.cirkul_spee,self.shape_widt,self.vector_spee,self.life_time,color,0,self.size_resize_timer]
                                                 
                                 else:
@@ -357,23 +367,23 @@ class Particles():
                     for i in range(len(self.particles)):
                         if self.shape == 'c':
                             if self.teni_fill:
-                                self.surf.GL.Circle(self.teni_color,[self.particles[i][0].vector.x+self.vector_teni[0],self.particles[i][0].vector.y+self.vector_teni[1]],self.particles[i][2],0,'s','D')
+                                self.draw_surf.GL.Circle(self.teni_color,[self.particles[i][0].vector.x+self.vector_teni[0],self.particles[i][0].vector.y+self.vector_teni[1]],self.particles[i][2],0,self.surf.screen,'D')
                             else:
-                                self.surf.GL.Circle(self.teni_color,[self.particles[i][0].vector.x+self.vector_teni[0],self.particles[i][0].vector.y+self.vector_teni[1]],self.particles[i][2],self.teni_size_obvodka,'s','D')
+                                self.draw_surf.GL.Circle(self.teni_color,[self.particles[i][0].vector.x+self.vector_teni[0],self.particles[i][0].vector.y+self.vector_teni[1]],self.particles[i][2],self.teni_size_obvodka,self.surf.screen,'D')
 
                         elif self.shape == 'r':
                             if self.teni_fill:
-                                self.surf.GL.Rect(self.teni_color,[self.particles[i][0].vector.x-self.particles[i][2]/2+self.vector_teni[0],self.particles[i][0].vector.y-self.particles[i][2]/2+self.vector_teni[1]],[self.particles[i][2],self.particles[i][2]],0,'s','D')
+                                self.draw_surf.GL.Rect(self.teni_color,[self.particles[i][0].vector.x-self.particles[i][2]/2+self.vector_teni[0],self.particles[i][0].vector.y-self.particles[i][2]/2+self.vector_teni[1]],[self.particles[i][2],self.particles[i][2]],0,self.surf.screen,'D')
 
 
                 for i in range(len(self.particles)):
 
                     if self.shape == 'r':
 
-                        self.surf.GL.Rect(self.particles[i][5],[self.particles[i][0].vector.x-self.particles[i][2]/2,self.particles[i][0].vector.y-self.particles[i][2]/2],[self.particles[i][2],self.particles[i][2]],0,'s','D')
+                        self.draw_surf.GL.Rect(self.particles[i][5],[self.particles[i][0].vector.x-self.particles[i][2]/2,self.particles[i][0].vector.y-self.particles[i][2]/2],[self.particles[i][2],self.particles[i][2]],0,self.surf.screen,'D')
                     elif self.shape == 'c':
 
-                        self.surf.GL.Circle(self.particles[i][5],self.particles[i][0].vector.xy,self.particles[i][2],0,'s','D')
+                        self.draw_surf.GL.Circle(self.particles[i][5],self.particles[i][0].vector.xy,self.particles[i][2],0,self.surf.screen,'D')
                     elif self.shape == 'i':
                         if self.randoming_image:
                             
@@ -397,28 +407,28 @@ class Particles():
                         
                         if self.light_radius_resize:
                             s1 = GL.Surfases_([self.particles[i][2]*4,self.particles[i][2]*4],[self.particles[i][0].vector.x-self.particles[i][2]*2,self.particles[i][0].vector.y-self.particles[i][2]*2],None,self.light_alpha,GL.S_Blend)
-                            if self.lighting_color=='shape_color':self.surf.GL.Circle([self.mult(self.particles[i][5][0]-self.light_color_dispers),self.mult(self.particles[i][5][1]-self.light_color_dispers),self.mult(self.particles[i][5][2]-self.light_color_dispers)],[self.particles[i][2]*2,self.particles[i][2]*2],self.particles[i][2]*2,0,s1.screen,'D')
-                            else:self.surf.GL.Circle(self.lighting_color,[self.particles[i][2]*2,self.particles[i][2]*2],self.particles[i][2]*2,0,s1.screen,'D')
+                            if self.lighting_color=='shape_color':self.draw_surf.GL.Circle([self.mult(self.particles[i][5][0]-self.light_color_dispers),self.mult(self.particles[i][5][1]-self.light_color_dispers),self.mult(self.particles[i][5][2]-self.light_color_dispers)],[self.particles[i][2]*2,self.particles[i][2]*2],self.particles[i][2]*2,0,s1.screen,'D')
+                            else:self.draw_surf.GL.Circle(self.lighting_color,[self.particles[i][2]*2,self.particles[i][2]*2],self.particles[i][2]*2,0,s1.screen,'D')
                             s1.DRAW_(self.surf.screen)
                         else:
                             if not self.light_radius_clip_in_shape_rad:
                                 s1 = GL.Surfases_([self.light_radius*2,self.light_radius*2],[self.particles[i][0].vector.x-self.light_radius,self.particles[i][0].vector.y-self.light_radius],None,self.light_alpha,GL.S_Blend)
-                                if self.lighting_color=='shape_color':self.surf.GL.Circle([self.mult(self.particles[i][5][0]-self.light_color_dispers),self.mult(self.particles[i][5][1]-self.light_color_dispers),self.mult(self.particles[i][5][2]-self.light_color_dispers)],[self.light_radius,self.light_radius],self.light_radius,0,s1.screen,'D')  
-                                else:self.surf.GL.Circle(self.lighting_color,[self.light_radius,self.light_radius],self.light_radius,0,s1.screen,'D')  
+                                if self.lighting_color=='shape_color':self.draw_surf.GL.Circle([self.mult(self.particles[i][5][0]-self.light_color_dispers),self.mult(self.particles[i][5][1]-self.light_color_dispers),self.mult(self.particles[i][5][2]-self.light_color_dispers)],[self.light_radius,self.light_radius],self.light_radius,0,s1.screen,'D')  
+                                else:self.draw_surf.GL.Circle(self.lighting_color,[self.light_radius,self.light_radius],self.light_radius,0,s1.screen,'D')  
                                 s1.DRAW_(self.surf.screen)
                             else:
                                 s1 = GL.Surfases_([self.mult(self.particles[i][2]*2+self.light_radius*2),self.mult(self.particles[i][2]*2+self.light_radius*2)],[self.particles[i][0].vector.x-(self.light_radius+self.particles[i][2]),self.particles[i][0].vector.y-(self.light_radius+self.particles[i][2])],None,self.light_alpha,GL.S_Blend)
-                                if self.lighting_color=='shape_color':self.surf.GL.Circle([self.mult(self.particles[i][5][0]-self.light_color_dispers),self.mult(self.particles[i][5][1]-self.light_color_dispers),self.mult(self.particles[i][5][2]-self.light_color_dispers)],[self.light_radius+self.particles[i][2],self.light_radius+self.particles[i][2]],self.light_radius+self.particles[i][2],0,s1.screen,'D')  
-                                else:self.surf.GL.Circle(self.lighting_color,[self.light_radius+self.particles[i][2],self.light_radius+self.particles[i][2]],self.light_radius+self.particles[i][2],0,s1.screen,'D')  
+                                if self.lighting_color=='shape_color':self.draw_surf.GL.Circle([self.mult(self.particles[i][5][0]-self.light_color_dispers),self.mult(self.particles[i][5][1]-self.light_color_dispers),self.mult(self.particles[i][5][2]-self.light_color_dispers)],[self.light_radius+self.particles[i][2],self.light_radius+self.particles[i][2]],self.light_radius+self.particles[i][2],0,s1.screen,'D')  
+                                else:self.draw_surf.GL.Circle(self.lighting_color,[self.light_radius+self.particles[i][2],self.light_radius+self.particles[i][2]],self.light_radius+self.particles[i][2],0,s1.screen,'D')  
                                 s1.DRAW_(self.surf.screen)
         
                     if self.soed_part_lines:
                         if self.coed_part_lines_centered:
                             
-                                self.surf.GL.Line(self.particles[i][5],self.particles[i][0].vector.xy,self.end_line_pos,int(self.particles[i][2]+self.coed_part_lines_add),'s','S','D')
+                                self.draw_surf.GL.Line(self.particles[i][5],self.particles[i][0].vector.xy,self.end_line_pos,int(self.particles[i][2]+self.coed_part_lines_add),self.surf.screen,'S','D')
                         else:
                             if len(self.particles)-i<len(self.particles):
-                                self.surf.GL.Line(self.particles[i][5],self.particles[i][0].vector.xy,self.particles[i-1][0].vector.xy,int(self.particles[i][2]+self.coed_part_lines_add),'s','S','D')
+                                self.draw_surf.GL.Line(self.particles[i][5],self.particles[i][0].vector.xy,self.particles[i-1][0].vector.xy,int(self.particles[i][2]+self.coed_part_lines_add),self.surf.screen,'S','D')
 
         def Focus(self):
             if self.start_focus:
